@@ -9,9 +9,15 @@ import requests
 import re
 import time
 import datetime as dt
+import sys
+import os
 
 name = 'telegram_util'
 
+def commitRepo():
+    command = 'git add . > /dev/null 2>&1 && git commit -m commit > /dev/null 2>&1 && git push -u -f > /dev/null 2>&1'
+    threading.Timer(60, lambda: os.system(command)).start()
+
 def cnWordCount(x):
 	return len([c for c in x if c.isalpha() and ord(c) > 255])
 
@@ -140,9 +146,10 @@ def log_on_fail(debug_group = None, error_to_ignore=[]):
 				tb.print_exc()
 				if debug_group:
 					debug_group.send_message(text=str(e)) 
-					# untested code
 					try:
-						debug_group.send_text(''.join(tb.format_tb()))
+						exc_type, exc_value, exc_traceback = sys.exc_info()
+						debug_group.send_message(''.join(
+							tb.format_tb(exc_traceback)))
 					except Exception as e:
 						debug_group.send_message(text=str(e)) 
 		return applicator
